# -*- coding: utf-8 -*-
#
# Copyright © 2019-2020 Nick Bowler
#
# License GPLv3+: GNU General Public License version 3 or any later version.
# This is free software: you are free to change and redistribute it.
# There is NO WARRANTY, to the extent permitted by law.

PLUGIN_NAME = u"Karaoke Flagger"
PLUGIN_AUTHOR = u"Nick Bowler"
PLUGIN_DESCRIPTION = u'''<p>This plugin sets a metadata variable for recordings
with the "karaoke version of" relation, so that tagger scripts can incorporate
this fact into file tags.</p>

<p>The metadata variable <code>%_karaoke%</code> will be set to "yes" on
karaoke tracks, and left unset otherwise.  So a tagger script might use
<code>$if(%_karaoke%,$set(comment:karaoke,%_karaoke%))</code>, for example,
to embed that into the file's comment tag.</p>
'''
PLUGIN_VERSION = "1"
PLUGIN_API_VERSIONS = ["2.0"]
PLUGIN_LICENSE = "GPL-3.0-or-later"

from picard import (config, log)
from picard.metadata import register_track_metadata_processor

def modulename():
    return modulename.__module__[len("picard.plugins."):]

def add_metadata(tagger, metadata, track, release):
    # for stanadlone recordings, "track" is actually a recording, not a track
    recording = track.get("recording", track)
    for r in recording["relations"]:
        # 'karaoke version of' is the backward relation of this type...
        if r["type-id"] != "39a08d0e-26e4-44fb-ae19-906f5fe9435d":
            continue
        if r["direction"] == "backward":
            metadata["~karaoke"] = "yes"
            return

if modulename() in config.setting["enabled_plugins"]:
    register_track_metadata_processor(add_metadata)
    log.info("%s activated" % (modulename()))
else:
    log.debug("%s disabled in configuration" % (modulename()))
